@@ -36,7 +36,7 @@ class DanbooruExtractor(BaseExtractor):
         username, api_key = self._get_auth_info()
         if username:
             self.log.debug("Using HTTP Basic Auth for user '%s'", username)
-            self.session.auth = (username, api_key)
+            self.session.auth = util.HTTPBasicAuth(username, api_key)
 
     def skip(self, num):
         pages = num // self.per_page
